// Copyright 2023 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import SwiftUI
import ArcGIS

struct ContentView: View {

    @State private var map = {
        // Creates a map with the topographic basemap style.
        let map = Map(basemapStyle: .arcGISTopographic)
        // Sets the initial viewpoint to Malibu, California.
        map.initialViewpoint = Viewpoint(latitude: 34.027, longitude: -118.805, scale: 72_000)

        // Creates an anonymous portal item pointing to https://www.arcgis.com with an item ID.
        let portalItem = PortalItem(
            portal: .arcGISOnline(connection: .anonymous),
            id: Item.ID("2e4b3df6ba4b44969a3bc9827de746b3")!
        )

        // Creates a feature layer from the portal item and a layer ID.
        let layer = FeatureLayer(featureServiceItem: portalItem, layerID: 0)
        // Adds the layer to the map's operational layers.
        map.addOperationalLayer(layer)

        return map
    }()


    var body: some View {
        // Displays the map.
        MapView(map: map)
    }
}

